@@ -40,6 +40,28 @@ macro_rules! bitmanip_impl {
                 v
             }
 
+            #[inline]
+            fn bit_first_one(&self) -> Option<usize> {
+                for i in 0..Self::bit_len() {
+                    if self.bit_get(i).unwrap() {
+                        return Some(i);
+                    }
+                }
+
+                None
+            }
+
+            #[inline]
+            fn bit_first_zero(&self) -> Option<usize> {
+                for i in 0..Self::bit_len() {
+                    if !self.bit_get(i).unwrap() {
+                        return Some(i);
+                    }
+                }
+
+                None
+            }
+
             #[inline]
             fn bit_len() -> usize {
                 Self::BITS as usize
@@ -102,6 +124,14 @@ pub trait BitManip {
     /// avoids needing to create two vectors and is thus faster.
     fn bit_zeroes(&self) -> Vec<usize>;
 
+    /// Returns the position of the first "on" bit in the number, or `None` if no bits are on.
+    /// Equivalent to `Self.bits().ones().first()`.
+    fn bit_first_one(&self) -> Option<usize>;
+
+    /// Returns the position of the first "off" bit in the number, or `None` if no bits are on.
+    /// Equivalent to `Self.bits().zeroes().first()`.
+    fn bit_first_zero(&self) -> Option<usize>;
+
     /// Gets the length of the implementor type in bits.
     fn bit_len() -> usize;
 
